Row

Struct Row 

pub struct Row<'a, T, I>
where I: Coordinate,
{ /* private fields */ }
Row is a quality-of-life assistant to ease processing matrices in a row-major fashion.

Implementations

Source

impl<'a, T, I> Row<'a, T, I>
where I: Coordinate,

pub fn row(&self) -> I

row returns the row number this Row represents, 0-based.

pub fn iter(&self) -> MatrixRowIterator<'a, T, I>

iter returns a bi-directional iterator over row.

pub fn get(&self, column: I) -> Option<&'a T>

get retrieves a specified column’s cell entry from this row.